import PropTypes from "prop-types";
import { motion, AnimatePresence } from "motion/react";
import clsx from "clsx";

function FormInput({ props, valid = true, className = "" }) {
  return (
    <div>
      <input
        {...props}
        className={clsx(
          `w-72 h-10 px-2 rounded-full dark:bg-white dark:text-grey border-2 text-grey focus:outline-grey ${className}`,
          !valid && "border-error"
        )}
      />
      <AnimatePresence>
        {!valid && (
          <motion.div
            className="text-sm text-error ml-3 pt-1"
            initial={{ y: 15, opacity: 0 }}
            animate={{ y: 0, opacity: 1 }}
            exit={{ y: 15, opacity: 0 }}
            key="cabinetIdError"
          >
            Invalid Value
          </motion.div>
        )}
      </AnimatePresence>
    </div>
  );
}

FormInput.propTypes = {
  props: PropTypes.object,
  valid: PropTypes.bool,
  className: PropTypes.string,
};

export default FormInput;
