import { useState } from "react";
import { useTranslation } from "react-i18next";
import FormBox from "../components/FormBox";
import Button from "../components/Button";
import { useNavigate } from "react-router-dom";
import FieldsWrapper from "../components/FieldsWrapper";
import FormField from "../components/FormField";
import FormInput from "../components/FormInput";
import FormSelect from "../components/FormSelect";

function CabinetCreation() {
  const { t } = useTranslation();
  const navigate = useNavigate();

  const [cabinetDetails, setCabinetDetails] = useState({
    cabinetId: "",
    cabinetIdValid: true,
    cabinetKeyId: "",
    cabinetKeyIdValid: true,
    noOfLockers: 0,
    noOfLockersValid: true,
  });

  const handleNext = (e) => {
    e.preventDefault();
    let isFormValid = true;
    const newValues = {...cabinetDetails};
    formFields.forEach(field => {
      if(field.validate) {
        const isFieldValid = field.validate(cabinetDetails[field.name])
        newValues[`${field.name}Valid`] = isFieldValid;
        if(!isFieldValid) isFormValid = false;
      }
    });
    
    if(!isFormValid) {
      setCabinetDetails(newValues);
      return;
    }

    navigate("register-lockers", {
      state: {
        cabinetId: cabinetDetails.cabinetId,
        cabinetKeyId: cabinetDetails.cabinetKeyId,
        noOfLockers: parseInt(cabinetDetails.noOfLockers),
      },
    });
  };

  const formFields = [
    {
      name: "cabinetId",
      label: t("cabinetId"),
      type: "input",
      maxLength: 6,
      validate: v => /^\w{2}\d{4}$/.test(v)
    },
    {
      name: "cabinetKeyId",
      label: t("cabinetKeyId"),
      type: "input",
      maxLength: 6,
      validate: v => /^\w{2}\d{4}$/.test(v)
    },
    {
      name: "noOfLockers",
      label: t("noOfLockers"),
      type: "input",
      subType: "number",
      validate: v => parseInt(v) > 0
    },
  ];

  const renderField = (field) => {
    const commonProps = {
      value: cabinetDetails[field.name],
      onChange: (e) => {
        const newCabinetDetails = { ...cabinetDetails };
        newCabinetDetails[field.name] = e.target.value.toUpperCase();
        newCabinetDetails[`${field.name}Valid`] = true;
        setCabinetDetails(newCabinetDetails);
      },
      maxLength: field.maxLength,
      type: field.subType,
    };
    const valid = cabinetDetails[`${field.name}Valid`];

    return (
      <FormField key={field.name} label={field.label}>
        {field.type === "input" ? (
          <FormInput props={commonProps} valid={valid} />
        ) : (
          <FormSelect
            props={commonProps}
            valid={valid}
            options={field.options}
          />
        )}
      </FormField>
    );
  };

  return (
    <FormBox title={t("cabinetCreation")}>
      <FieldsWrapper>
        {formFields.map(renderField)}
      </FieldsWrapper>
      <Button text={t('next')} onClick={handleNext} />
    </FormBox>
  );
}

export default CabinetCreation;
